# Editorial - SmartCargo

### Generarea datasetului

Datele au fost create pentru a simula curse reale intre orasele din Romania. Lista completa de orase include coordonate GPS, regiuni geografice (campie, munte, litoral) si populatii. Pentru fiecare pereche de orase, distantele rutiere reale au fost calculate folosind serviciul OSRM (Open Source Routing Machine).

Datele de antrenament si evaluare au fost generate astfel:
- Fiecare livrare include informatii despre orasele de plecare si destinatie, distanta, ora din zi (in minute de la miezul noptii), conditii meteo (Clear, Rain, Snow, Fog), trafic, calitatea drumului si experienta soferului.
- Timpul de livrare (`deliver_time`) este generat printr-o functie liniara ce combina toti acesti factori intr-un mod controlat, adaugand zgomot normal mic, pentru a favoriza modelele liniare precum Lasso si Linear Regression.

Aceasta abordare face ca modelele care realizeaza un feature engineering adecvat si folosesc regresori liniari sa poata obtine scoruri mai bune decat Random Forest sau Decision Tree, utilizand resurse computationale mai reduse.

### Descrierea solutiilor

A. Task-ul T1 cere numarul de curse in care orasul de plecare este Barlad si vremea este ceata.

Solutia presupune o filtrare simpla folosind Pandas, prin selectarea liniilor care indeplinesc ambele conditii si numararea acestora. Rezultatul este salvat intr-un fisier CSV conform cerintelor.


B. Task-ul T2 implica antrenarea unui model de regresie pentru a estima deliver_time pentru noile curse din setul de date de predictie.

#### a) Solutia simpla

Prima solutie propune:
- Un model Random Forest simplu (n_estimators=100), fara optimizare de hiperparametri.
- Aplicarea Label Encoding pe campurile textuale (City A, City B, Weather).
- Fara scalari numerice sau altele tehnici de preprocesare.
- Fara optimizare a hiperparametrilor.

Aceasta abordare obtine in mod tipic aproximativ 62-65 puncte.

Limitare: Modelele de tip Random Forest nu valorifica forma liniara a relatiei generate, iar lipsa scalarii penalizeaza regresorii liniari.

#### b) Solutia imbunatatita

A doua solutie adauga Feature Engineering:
- Scalare StandardScaler pe variabilele numerice:
  - Distance
  - Time of Day
  - Road Quality
  - Traffic
  - Driver Experience
- Antrenarea mai multor modele:
  - Random Forest cu 100 si 300 arbori
  - Decision Tree
  - Linear Regression
  - Lasso Regression cu alpha=0.1
  - Ridge Regression cu alpha=0.1

Observatie cheie: Datorita naturii aproape liniare a functiei de generare a datelor, modelele Lasso sau Linear Regression se comporta mult mai bine cu scalare numerica corecta. Insa se putea obtine un scor de 100 puncte si fara scalare.

## Concluzie

Pentru a atinge performanta maxima:
- Este esentiala adaugarea scalarii pe variabilele numerice.
- Alegerea modelului trebuie adaptata formei relatiei: aici, regresorii liniari sunt superiori modelelor de tip Random Forest sau Decision Tree.
- Optimizarea parametrului alpha pentru Lasso poate creste suplimentar acuratetea.

