'''
Functiile de mai jos au fost folosite pentru a calcula metrica si scorul pentru fiecare subtask individual

Fiecare primeste un parametru ("submission") care este un dataframe cu 3 coloane:
    - ID = id-ul din setul de date de test
    - correct_values = valorile din ground truth
    - output_values = valorile trimise de voi

Pentru fiecare subtask, dataframe-ul cu care se apeleaza functia va contine doar liniile corespunzatoare
subtaskului respectiv

Functiile returneaza:
    - partial_score = scorul pe o parte din setul de date de test
    - partial_metric = metrica pe o parte din setul de date de test
    - complete_score = scorul pe toate datele de test
    - complete_metric = metrica pe toate datele de test
'''

import numpy as np
from sklearn import metrics, model_selection

def subtask1(submission):
    acc = 1 if abs(float(submission['correct_values']) - float(submission['output_values'])) < 1e-4 else 0
    score = acc * 21
    return score, acc, score, acc

def subtask2(submission):
    partial, rest = model_selection.train_test_split(submission, train_size=0.5, random_state=0)

    # Interpolation such that at min_value you get score_min, at max_value you get score_max
    def lerp(value, min_value, max_value, score_min, score_max) -> int:
        slide = np.clip((value - min_value) / (max_value - min_value), 0.0, 1.0)
        score_res = score_min + (score_max - score_min) * slide
        return int(score_res)

    def score_and_metric(dataframe):
        mae = metrics.mean_absolute_error(list(dataframe['correct_values']), list(dataframe['output_values']))
        score = 0
        if mae >= 100:
            score = 0
        elif mae >= 20:
            score = lerp(mae, 100.0, 20.0, 0, 10)
        elif mae >= 10.0:
            score = lerp(mae, 20.0, 10.0, 10, 30)
        elif mae >= 8.0:
            score = lerp(mae, 10.0, 8.0, 30, 40)
        elif mae >= 5.0:
            score = lerp(mae, 8.0, 5.0, 40, 60)
        elif mae >= 4.5:
            score = lerp(mae, 5.0, 4.5, 60, 70)
        else:
            score = lerp(mae, 4.5, 4.3, 70, 79)

        return score, mae

    partial_score, partial_metric = score_and_metric(partial)
    complete_score, complete_metric = score_and_metric(submission)

    return partial_score, partial_metric, complete_score, complete_metric